@@ -26,3 +26,13 @@ def test_get_eth_balance(address: str, networks_clients: Dict[str, BaseClient])
         balance = client.getBalanceInWei(address)
         assert type(balance) is int
         assert balance >= 0
+
+
+def test_get_sign_message(
+    private_key: str, networks_clients: Dict[str, BaseClient]
+) -> None:
+    msg = "Hello world!"
+    for network, client in networks_clients.items():
+        client.setAccount(privateKey=private_key)
+        signed_message = client.signMessage(msg)
+        assert client.isMessageSignedByMe(msg, signed_message)
